==> slapos.cookbook-1.0.139.tar.gz: slapos.cookbook-1.0.139/slapos/recipe/check_port_listening.py <==
# vim: set et sts=2:
##############################################################################
#
# Copyright (c) 2011 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
from slapos.recipe.librecipe import GenericBaseRecipe
from zc.buildout.easy_install import _safe_arg, script_header
import sys

template = script_header + r"""
# BEWARE: This file is operated by slapgrid
# BEWARE: It will be overwritten automatically
import socket
import sys

addr = "%(hostname)s", %(port)s

try:
  socket.create_connection(addr).close()
except (socket.error, socket.timeout):
  sys.stderr.write("%%s on %%s isn't listening\n" %% addr)
  sys.exit(127)
"""

class Recipe(GenericBaseRecipe):
  """
  Check listening port promise
  """

  def install(self):
    promise = self.createExecutable(self.options['path'], template % {
      'python': _safe_arg(sys.executable),
      'dash_S': '', # BBB buildout 1.x
      'hostname': self.options['hostname'],
      'port': self.options['port'],
      })

    return [promise]

==> slapos.cookbook-1.0.244.tar.gz: slapos.cookbook-1.0.244/slapos/recipe/check_port_listening.py <==
# vim: set et sts=2:
##############################################################################
#
# Copyright (c) 2011 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
from slapos.recipe.librecipe import GenericBaseRecipe
from zc.buildout.easy_install import _safe_arg, script_header
import sys

template = script_header + r"""
# BEWARE: This file is operated by slapos node
# BEWARE: It will be overwritten automatically
import socket
import sys

addr = "%(hostname)s", %(port)s

try:
  socket.create_connection(addr).close()
except (socket.error, socket.timeout):
  sys.stderr.write("%%s on %%s isn't listening\n" %% addr)
  sys.exit(127)
"""

class Recipe(GenericBaseRecipe):
  """
  Check listening port promise
  """

  def install(self):
    promise = self.createExecutable(self.options['path'], template % {
      'python': _safe_arg(sys.executable),
      'dash_S': '', # BBB buildout 1.x
      'hostname': self.options['hostname'],
      'port': self.options['port'],
      })

    return [promise]
